@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -31,10 +30,10 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
 
+from collections.abc import Mapping, Sequence
 from types import TracebackType
-from typing import Any, List, Mapping, Optional, Sequence, Type
+from typing import Any
 
 from univention.listener import ListenerModuleConfiguration, ListenerModuleHandler
 
@@ -47,7 +46,7 @@ class ComplexHandler(ListenerModuleHandler):
         description = 'a description'
         ldap_filter = '(objectClass=inetOrgPerson)'
 
-        def get_attributes(self) -> List[str]:
+        def get_attributes(self) -> list[str]:
             # do more complicated stuff than just setting the class variable...
             return ['cn']
 
@@ -61,7 +60,7 @@ class ComplexHandler(ListenerModuleHandler):
         # The log level for messages that go to
         # :file:`/var/log/univention/listener_modules/my_listener_module.log` is set
         # with the UCR variable `listener/module/my_listener_module/debug/level`.
-        super(ComplexHandler, self).__init__(listener_configuration, *args, **kwargs)
+        super().__init__(listener_configuration, *args, **kwargs)
         self.logger.info('ComplexHandler.__init__()')
         self.logger.debug('DEBUG level message')
         self.logger.info('INFO level message')
@@ -71,7 +70,7 @@ class ComplexHandler(ListenerModuleHandler):
     def create(self, dn: str, new: Mapping[str, Sequence[bytes]]) -> None:
         self.logger.info('ComplexHandler.create() dn=%r', dn)
 
-    def modify(self, dn: str, old: Mapping[str, Sequence[bytes]], new: Mapping[str, Sequence[bytes]], old_dn: Optional[str]) -> None:
+    def modify(self, dn: str, old: Mapping[str, Sequence[bytes]], new: Mapping[str, Sequence[bytes]], old_dn: str | None) -> None:
         # modify() will be called for both moves and modifies.
         # If `old_dn` is set, a move happened.
         # Both DN an attributes can change during a move.
@@ -92,19 +91,19 @@ class ComplexHandler(ListenerModuleHandler):
         # The error handler will *not* return here. After all this is an unhandled exception.
 
     def initialize(self) -> None:
-        super(ComplexHandler, self).initialize()
+        super().initialize()
         self.logger.info('ComplexHandler.initialize()')
 
     def clean(self) -> None:
-        super(ComplexHandler, self).clean()
+        super().clean()
         self.logger.info('ComplexHandler.clean()')
 
     def pre_run(self) -> None:
-        super(ComplexHandler, self).pre_run()
+        super().pre_run()
         self.logger.info('ComplexHandler.pre_run()')
 
     def post_run(self) -> None:
-        super(ComplexHandler, self).post_run()
+        super().post_run()
         self.logger.info('ComplexHandler.post_run()')
 
     def error_handler(
@@ -113,9 +112,9 @@ class ComplexHandler(ListenerModuleHandler):
             old: Mapping[str, Sequence[bytes]],
             new: Mapping[str, Sequence[bytes]],
             command: str,
-            exc_type: Optional[Type[BaseException]],
-            exc_value: Optional[BaseException],
-            exc_traceback: Optional[TracebackType],
+            exc_type: type[BaseException] | None,
+            exc_value: BaseException | None,
+            exc_traceback: TracebackType | None,
     ) -> None:
         # `exc_type`, `exc_value` and `exc_traceback` can be examined for further
         # information about the exception.
