@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -31,35 +30,32 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
-
-from typing import Dict, List, Optional
 
 from univention.listener import ListenerModuleHandler
 
 
 class ListenerModuleTemplate(ListenerModuleHandler):
 
-    class Configuration(object):
+    class Configuration:
         name = 'unique_name'
         description = 'listener module description'
         ldap_filter = '(&(objectClass=inetOrgPerson)(uid=example))'
         attributes = ['sn', 'givenName']
 
-    def create(self, dn: str, new: Dict[str, List[bytes]]) -> None:
+    def create(self, dn: str, new: dict[str, list[bytes]]) -> None:
         self.logger.debug('dn: %r', dn)
 
     def modify(
             self,
             dn: str,
-            old: Dict[str, List[bytes]],
-            new: Dict[str, List[bytes]],
-            old_dn: Optional[str],
+            old: dict[str, list[bytes]],
+            new: dict[str, list[bytes]],
+            old_dn: str | None,
     ) -> None:
         self.logger.debug('dn: %r', dn)
         if old_dn:
             self.logger.debug('it is (also) a move! old_dn: %r', old_dn)
         self.logger.debug('changed attributes: %r', self.diff(old, new))
 
-    def remove(self, dn: str, old: Dict[str, List[bytes]]) -> None:
+    def remove(self, dn: str, old: dict[str, list[bytes]]) -> None:
         self.logger.debug('dn: %r', dn)
