@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -30,10 +29,10 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
 
 import sys
-from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Optional, Sequence, Tuple  # noqa: F401
+from collections.abc import Mapping, Sequence  # noqa: F401
+from typing import TYPE_CHECKING
 
 
 if TYPE_CHECKING:
@@ -41,7 +40,7 @@ if TYPE_CHECKING:
     from .handler_configuration import ListenerModuleConfiguration  # noqa: F401
 
 
-class ListenerModuleAdapter(object):
+class ListenerModuleAdapter:
     """
     Adapter to convert the :py:mod:`univention.listener.listener_module interface` to
     the existing listener module interface.
