@@ -5,7 +5,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2004-2023 Univention GmbH
+ * Copyright 2004-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -321,7 +321,7 @@ int change_update_schema(univention_ldap_parameters_t *lp) {
 
 	free(server_role);
 
-	if ((notifier_get_schema_id_s(NULL, &new_id)) != 0) {
+	if ((NOTIFIER_RETRY(notifier_get_schema_id_s(NULL, &new_id))) != 0) {
 		univention_debug(UV_DEBUG_LISTENER, UV_DEBUG_ERROR, "failed to get schema DN");
 		return LDAP_OTHER;
 	}
