@@ -39,7 +39,7 @@
 #include <stdbool.h>
 #include <sys/types.h>
 #include <ldap.h>
-#include <python3.7/Python.h>
+#include <python3.11/Python.h>
 #include <univention/ldap.h>
 
 #include "cache.h"
@@ -66,7 +66,7 @@ struct _Handler {
 	char *description;
 	struct filter **filters;
 	char **attributes;
-	char *modrdn;
+	bool modrdn;
 	bool handle_every_delete;
 	PyObject *handler;
 	PyObject *initialize;
