@@ -5,7 +5,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2004-2023 Univention GmbH
+ * Copyright 2004-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -58,6 +58,7 @@
 #include "network.h"
 #include "select_server.h"
 #include "transfile.h"
+#include "utils.h"
 
 int INIT_ONLY = 0;
 
@@ -329,7 +330,7 @@ static int do_connection(univention_ldap_parameters_t *lp) {
 		univention_debug(UV_DEBUG_LISTENER, UV_DEBUG_WARN, "can not connect to LDAP server %s:%d", lp->uri ? lp->uri : lp->host ? lp->host : "NULL", lp->port);
 		goto fail;
 	}
-	if (notifier_client_new(NULL, lp->host, 1) != 0)
+	if (NOTIFIER_CLIENT_NEW_RETRY(notifier_client_new(NULL, lp->host, 1)) != 0)
 		goto fail;
 
 	/* check if we are connected to an OpenLDAP */
@@ -573,7 +574,7 @@ int main(int argc, char *argv[]) {
 	if (lp->host != NULL)
 		handlers_set_data_all("ldapserver", lp->host);
 
-	if (notifier_get_id_s(NULL, &id) != 0) {
+	if (NOTIFIER_RETRY(notifier_get_id_s(NULL, &id)) != 0) {
 		univention_debug(UV_DEBUG_LISTENER, UV_DEBUG_ERROR, "failed to receive current ID");
 		return 1;
 	}
@@ -587,7 +588,7 @@ int main(int argc, char *argv[]) {
 	if (rv == MDB_NOTFOUND) {
 		cache_get_int("notifier_id", &cache_master_entry.id, -1);
 		if (cache_master_entry.id == -1) {
-			rv = notifier_get_id_s(NULL, &cache_master_entry.id);
+			rv = NOTIFIER_RETRY(notifier_get_id_s(NULL, &cache_master_entry.id));
 			if (rv != 0) {
 				univention_debug(UV_DEBUG_LISTENER, UV_DEBUG_ERROR, "failed to receive current ID");
 				return 1;
