@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Directory Listener
 #
@@ -35,7 +34,6 @@
 
 """Read the notifier id from the Primary Directory Node"""
 
-from __future__ import print_function
 
 import argparse
 import socket
@@ -86,7 +84,7 @@ def main():
 
         if notifier_result:
             print("%s" % notifier_result.decode('UTF-8', 'replace').splitlines()[1])
-    except socket.error as ex:
+    except OSError as ex:
         print('Error: %s' % (ex,), file=sys.stderr)
         sys.exit(1)
 
