@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Directory Listener
 #
@@ -35,7 +34,6 @@
 
 """Resync objects from Primary to local LDAP database"""
 
-from __future__ import print_function
 
 import argparse
 
